# v1.0.0 Release Goal

To be promoted to the first 1.x.x major release, this project should:

- [ ] Have 100% direct REQ coverage
- [ ] Have 95% test coverage
- [ ] Have 100% tests passing
- [ ] Be validated that all REQs, help, CLI docs, docs/ are up-to-date and accurate
- [ ] Have an auto-deploy mechanism
